@@ -6,11 +6,12 @@ class TorrentNumberCondition(ConditionWithSort):
         self._max_limit = settings['limit']
 
     def apply(self, torrents):
+        torrents = list(torrents)
         ConditionWithSort.sort_torrents(self, torrents)
         if self._max_limit == 0:
             self.remove = torrents
         elif self._max_limit < len(torrents):
-            self.remain = torrents[0:self._max_limit-1]
-            self.remove = torrents[self._max_limit:]
+            self.remove = set(torrents[0:len(torrents)-self._max_limit])
+            self.remain = set(torrents[len(torrents)-self._max_limit:])
         else:
             self.remain = torrents
\ No newline at end of file
