@@ -7,6 +7,7 @@ import yaml
 from . import logger
 from .task import Task
 from autoremovetorrents.version import __version__
+from autoremovetorrents.compatibility.open_ import open_
 
 def pre_processor(argv):
     # View Mode
@@ -44,7 +45,7 @@ def pre_processor(argv):
         lg.info('Auto Remove Torrents %s' % __version__)
         # Load configurations
         lg.info('Loading configurations...')
-        with open(conf_path, 'r') as stream:
+        with open_(conf_path, 'r', encoding='utf-8') as stream:
             result = yaml.safe_load(stream)
         lg.info('Found %d task(s) in the file.' % len(result))
 
